{
  config,
  pkgs,
  lib,
  inputs,
  ...
}: {
  home.username = "blue";
  home.homeDirectory = "/home/blue";

  imports = [
    ./hyprland.nix
    ./waybar.nix
    ./swaync.nix
    ./hyprlock.nix
    ./zsh.nix
    ./eza.nix
    ./nvf.nix
    ./nextcloud.nix
    ./git.nix
    ./stylix.nix
    ./direnv.nix
  ];

  # States home manager version that config was originally compatible with, do not change without reading all patch notes since this version and altering as needed
  home.stateVersion = "24.05";

  #  services.pass-secret-service.enable = true; # for use with protonmail-bridge
  services.gnome-keyring.enable = true; # used for protonmail-bridge and nextcloud-client

  # General use home packages that dont require a separate module
  home.packages = with pkgs; [
    # Add grimblast screenshot tool
    grimblast
    powerline-fonts
    nix-output-monitor
    #   bitwarden-desktop
    xwaylandvideobridge
    virtualbox
    wofi
    lsp-plugins
    nvtopPackages.amd
    signal-desktop
    nautilus
    element-desktop
    jetbrains.idea-community
  ];
  services.flatpak.packages = [
    "io.mrarm.mcpelauncher"
  ];

  home.sessionVariables = {
    DEFAULT_BROWSER = "${lib.getExe pkgs.firefox}";
    # Allow XWayland apps to not be weird after turning off xwayland scaling in hyprland.conf
    GDK_SCALE = 1;
    XCURSOR_SIZE = 24;
    # Set default editor
    EDITOR = "nvim";
    NIXOS_OZONE_WL = 1 ;
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  programs.tmux.enable = true;

  programs.btop.enable = true;
  programs.btop.package = pkgs.stable.btop-rocm;

  # Add support for bluetooth headset media controls
  services.mpris-proxy.enable = true;

  programs.alacritty = {
    enable = true;
    package = pkgs.alacritty;
    settings = {
      window.dimensions = {
        lines = 3;
        columns = 200;
      };
      #      font.normal = {
      #        family = "hack";
      #      };
      #      keyboard.bindings = [
      #        {
      #          key = "K";
      #          mods = "Control";
      #          chars = "\\u000c";
      #        }
      #      ];
    };
  };

  #  programs.hyprpaper = {
  #    enable = true;
  #    settings = {
  #      ipc = "on";
  #      splash = false;
  #      splash_offset = 2.0;

  #      preload = [ "~/Pictures/wallpaper.png" ];

  #      wallpaper = [
  #        ",~/Pictures/wallpaper.png"
  #      ];
  #    };
  #  };

  services.blueman-applet.enable = true;
}
